Module: OpenapiRuby::Adapters::Minitest
- Defined in:
- lib/openapi_ruby/adapters/minitest.rb
Defined Under Namespace
Modules: DSL
Class Method Summary collapse
Class Method Details
.install! ⇒ Object
193 194 195 196 197 198 |
# File 'lib/openapi_ruby/adapters/minitest.rb', line 193 def self.install! # Schema writing is handled by the rake task (openapi_ruby:generate), # not by test runs. The rake task loads test files to register DSL # contexts, then calls SchemaWriter.generate_all! directly. # This prevents partial schema overwrites when running a subset of tests. end |