Module: OpenapiRuby::Generator::TestSchemaSuppressor::MigrationSilencer

Defined in:
lib/openapi_ruby/generator/test_schema_suppressor.rb

Instance Method Summary collapse

Instance Method Details

#check_all_pending!Object

Not called by Rails during boot, but a common addition to a hand-written test_helper. Same intent as the above: assert the test database matches the migrations. Nothing is loaded from the database to build the document, so there is nothing to verify.



49
50
51
# File 'lib/openapi_ruby/generator/test_schema_suppressor.rb', line 49

def check_all_pending!
  nil
end

#maintain_test_schema!Object

Called by rails/test_help at require time.



41
42
43
# File 'lib/openapi_ruby/generator/test_schema_suppressor.rb', line 41

def maintain_test_schema!
  nil
end