Module: OpenapiRuby::Adapters::RSpec
- Defined in:
- lib/openapi_ruby/adapters/rspec.rb
Defined Under Namespace
Modules: ExampleGroupHelpers, ExampleHelpers
Class Method Summary collapse
Class Method Details
.install! ⇒ Object
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/openapi_ruby/adapters/rspec.rb', line 272 def self.install! ::RSpec.configure do |config| config.extend ExampleGroupHelpers, type: :openapi config.include ExampleHelpers, type: :openapi if defined?(::RSpec::Rails) config.include ::RSpec::Rails::RequestExampleGroup, type: :openapi end # Schema writing is handled by the rake task (openapi_ruby:generate), # not by test runs. The rake task loads spec files to register DSL # contexts, then calls SchemaWriter.generate_all! directly. # This prevents partial schema overwrites when running a subset of specs. end end |